@@ -4,7 +4,7 @@
  * GChemPaint library
  * tool.cc
  *
- * Copyright (C) 2001-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -47,6 +47,7 @@ Tool::Tool (Application *App, string Id)
 	m_bChanged = m_bPressed = false;
 	m_pData = NULL;
 	m_OwnStatus = false;
+	m_nState = 0;
 }
 
 Tool::~Tool ()
@@ -94,7 +95,7 @@ void Tool::OnMotion (View* pView, Object* pObject, double x, double y, unsigned
 	OnMotion ();
 }
 
-void Tool::OnLeaveNotify (View* pView, unsigned int state)
+void Tool::OnLeaveNotify (View* pView, G_GNUC_UNUSED unsigned int state)
 {
 	m_pView = pView;
 	m_pData = pView->GetData ();
@@ -142,6 +143,8 @@ bool Tool::Activate (bool bState)
 		return true;
 	} else {
 		if (Deactivate ()) {
+			if (m_pWidget)
+				gdk_window_set_cursor (gtk_widget_get_parent_window (m_pWidget), NULL);
 			m_pObject = NULL;
 			m_pWidget = NULL;
 			m_pView = NULL;
@@ -218,7 +221,7 @@ bool Tool::DeleteSelection ()
 
 bool Tool::CopySelection (G_GNUC_UNUSED GtkClipboard *clipboard)
 {
-	return false;
+	return true; // makes copying impossible
 }
 
 bool Tool::CutSelection (G_GNUC_UNUSED GtkClipboard *clipboard)
