@@ -2,7 +2,7 @@
  * Gnome Chemistry Utils
  * element.cc 
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,7 +23,7 @@
 #include "config.h"
 #include "element.h"
 #include "xml-utils.h"
-#include <goffice/math/go-math.h>
+#include <goffice/goffice.h>
 #include <libxml/parser.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
@@ -98,6 +98,7 @@ EltTable::EltTable()
 	Langs["pl"] = _("Polish");
 	Langs["pt_BR"] = _("Brazilian");
 	Langs["ru"] = _("Russian");
+	Langs["zh_TW"] = _("Chinese (TW)");
 	if (!(xml = xmlParseFile (PKGDATADIR"/elements.xml"))) {
 		g_error (_("Can't find and read elements.xml"));
 	}
@@ -287,8 +288,13 @@ Element::Element(int Z, const char* Symbol):
 Element::~Element()
 {
 	while (!m_radii.empty()) {
-		delete m_radii.back();
-		m_radii.pop_back();
+		GcuAtomicRadius *radius = m_radii.back ();
+		if (radius) {
+			if (radius->scale)
+				g_free (const_cast <char *> (radius->scale));
+			delete radius;
+		}
+		m_radii.pop_back ();
 	}
 	while (!m_en.empty()) {
 		delete m_en.back();
@@ -298,6 +304,10 @@ Element::~Element()
 		delete (m_isotopes.back ());
 		m_isotopes.pop_back ();
 	}
+	while (!m_patterns.empty ()) {
+		delete (m_patterns.back ());
+		m_patterns.pop_back ();
+	}
 	map<string, Value*>::iterator i, iend = props.end ();
 	for (i = props.begin (); i != iend; i++)
 		delete (*i).second;
@@ -425,6 +435,7 @@ void Element::LoadRadii ()
 			}
 			num = (char*) xmlGetProp (node, (xmlChar*) "Z");
 			Elt = Table[Z = atoi (num)];
+			xmlFree (num);
 			if (!Elt) {
 				node = node->next;
 				continue;
@@ -450,7 +461,8 @@ void Element::LoadRadii ()
 							xmlFree (buf);
 						child = child->next;
 						continue;
-					}
+					} else if (buf)
+						xmlFree (buf);
 					buf = (char*) xmlGetProp (child, (xmlChar*) "scale");
 					if (buf) {
 						radius->scale = g_strdup (buf);
@@ -888,8 +900,11 @@ void Element::LoadBODR ()
 							buf = (char*) xmlGetProp (child, (xmlChar const*) "dictRef");
 							if (elt)
 								elt->props[(strncmp (buf, "bo:", 3))? buf: buf + 3] = val;
+							else
+								delete val;
 							xmlFree (buf);
 						} else if (!strcmp (buf, "xsd:String") || !strcmp (buf, "xsd:string")) {
+							xmlFree (buf);
 							buf = (char*) xmlGetProp (child, (xmlChar const*) "dictRef");
 							char *val = (char*) xmlNodeGetContent (child);
 							if (elt)
@@ -917,7 +932,8 @@ void Element::LoadBODR ()
 							if (elt && !strcmp (buf, "bo:discoveryDate"))
 								elt->iprops["discoveryDate"] = val;
 							xmlFree (buf);
-						}
+						} else
+							xmlFree (buf);
 					}
 					if (props.size () > 0) {
 						if (elt) {
